@@ -7,14 +7,11 @@ from herolabsapi.const import (
     SIGN_OUT_RESOURCE,
     USER_RESOURCE,
     RESET_PASSWORD_RESOURCE,
-    LIST_SONICS_RESOURCE,
-    LIST_SONICS_WIFI_RESOURCE,
-    LIST_TELEMETRY_RESOURCE,
-    LIST_SIGNALS_RESOURCE,
-    FETCH_PROPERTY_SETTINGS_RESOURCE,
-    LIST_PROPERTIES_RESOURCE,
-    FETCH_NOTIFICATION_SETTINGS_RESOURCE,
-    LIST_INCIDENTS_RESOURCE,)
+    SONICS_RESOURCE,
+    SONICS_WIFI_RESOURCE,
+    SIGNALS_RESOURCE,
+    PROPERTIES_RESOURCE,
+    INCIDENTS_RESOURCE,)
 from herolabsapi.user import User
 from herolabsapi.sonic import Sonic
 from herolabsapi.signals import Signals
